@@ -1,4 +1,5 @@
 from aiaccel.torch.lightning.abci_environment import ABCIEnvironment
+from aiaccel.torch.lightning.ckpt import load_checkpoint
 from aiaccel.torch.lightning.opt_lightning_module import OptimizerConfig, OptimizerLightningModule, build_param_groups
 
-__all__ = ["ABCIEnvironment", "OptimizerConfig", "OptimizerLightningModule", "build_param_groups"]
+__all__ = ["ABCIEnvironment", "OptimizerConfig", "OptimizerLightningModule", "build_param_groups", "load_checkpoint"]
